Validation functions
Structs
- Validation
Limits - Validation limits for safety & sanity checking, to help prevent resource exhaustion. All limits can be adjusted at client creation time
Functions
- looks_
like_ object_ id - Determine if a string is (probably) an object id or space id, using syntactic checks. Does not check whether the apparent-id represents an actual object.